# CalculatePy is the fundamental package for mathematical operations with Python.

### This package provides flexibility to the user to provide numbers is any format (string, int, float) whether as individual numbers are in an array.

## It provides:

- Addition
  - This function has flexibility in accepting numbers as 
    - individual argument like "add(1,2)" or 
    - in a list like "add([1,2])" or 
    - in a set like "add((1,2))" or "add({1,2})"
  - Numbers can be passed as a string ``add('1', '2')``
  - Any non number characters will be considered as ``0`` value without throwing an error
- Subtraction
  - This function has flexibility in accepting numbers as 
      - individual argument like "subtract(1,2)" or 
      - in a list like "subtract([1,2])" or 
      - in a set like "subtract((1,2))" or "subtract({1,2})"
  - Numbers can be passed as a string ``subtract('1', '2')``
  - Any non number characters will be considered as ``0`` value without throwing an error
- Multiplication
  - This function has flexibility in accepting numbers as 
      - individual argument like "multiply(1,2)" or 
      - in a list like "multiply([1,2])" or 
      - in a set like "multiply((1,2))" or "multiply({1,2})"
  - Numbers can be passed as a string ``multiply('1', '2')``
  - Any non number characters will be considered as ``1`` value without throwing an error

